@@ -1,4 +1,4 @@
-/* $Id: libgdamm.h 911 2007-01-13 19:32:27Z murrayc $ */
+/* $Id: libgdamm.h 977 2007-02-04 12:12:32Z arminb $ */
 /* libgdamm - a C++ wrapper for libgda
  *
  * Copyright 1999-2001 Free Software Foundation
@@ -38,7 +38,12 @@ extern const int libgdamm_micro_version;
 #include <libgdamm/connection.h>
 #include <libgdamm/datamodel.h>
 #include <libgdamm/connectionevent.h>
+#include <libgdamm/datamodelarray.h>
 #include <libgdamm/datamodelquery.h>
 #include <libgdamm/query.h>
+#include <libgdamm/queryfieldagg.h>
+#include <libgdamm/queryfieldall.h>
+#include <libgdamm/queryfieldfield.h>
+#include <libgdamm/queryfieldvalue.h>
 
 #endif /* #ifndef LIBGDAMM_H */
