@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gda.cc 923 2007-01-17 21:17:47Z arminb $ */
+/* $Id: generate_defs_gda.cc 976 2007-02-04 11:09:01Z arminb $ */
 
 /* generate_defs_gda.h
  *
@@ -49,7 +49,16 @@ int main (int argc, char *argv[])
                  << get_defs(GDA_TYPE_PARAMETER_LIST)
 //                 << get_defs(GDA_TYPE_RECORDSET)
                  << get_defs(GDA_TYPE_QUERY)
-                 << get_defs(GDA_TYPE_QUERY_OBJECT);
+                 << get_defs(GDA_TYPE_QUERY_OBJECT)
+                 << get_defs(GDA_TYPE_QUERY_FIELD)
+                 << get_defs(GDA_TYPE_QUERY_TARGET)
+                 << get_defs(GDA_TYPE_QUERY_CONDITION)
+                 << get_defs(GDA_TYPE_QUERY_JOIN)
+                 << get_defs(GDA_TYPE_QUERY_FIELD_AGG)
+                 << get_defs(GDA_TYPE_QUERY_FIELD_ALL)
+                 << get_defs(GDA_TYPE_QUERY_FIELD_FIELD)
+                 << get_defs(GDA_TYPE_QUERY_FIELD_FUNC)
+                 << get_defs(GDA_TYPE_QUERY_FIELD_VALUE);
 //                 << get_defs(GDA_TYPE_SERVER_CONNECTION)
 //                 << get_defs(GDA_TYPE_SERVER_PROVIDER)
 //                 << get_defs(GDA_TYPE_SERVER_RECORDSET_MODEL)
